<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\AbonoEstuiante;
use App\Models\Caja;
use App\Models\Cierre;
use App\Models\CreditoEstuiante;
use App\Models\CuadreReceso;
use App\Models\Menu;
use App\Models\Venta;
use Illuminate\Http\Request;

class ReporteController extends Controller
{

    public function index()
    {
        return view('admin.repote.index');
    }

    // retorna los movimientos de un dia actual
    public function movimiento_hoy()
    {
        $entradas = $this->listDataToCajaForCierre();
        $salidas = $this->listDataToCajaForCierre('Salida');
        $recesos = CuadreReceso::whereDate('created_at', date('Y-m-d'))->get();
        $cierres = Cierre::whereDate('created_at', date('Y-m-d'))->get();
        $ventas = Venta::whereDate('created_at', date('Y-m-d'))->get();

        $abonos = AbonoEstuiante::whereDate('created_at', date('Y-m-d'))->get();
        $credito = CreditoEstuiante::whereDate('created_at', date('Y-m-d'))->get();

        // dd($credito);

        return view('admin.repote.hoy', compact('entradas', 'salidas', 'recesos', 'cierres', 'ventas', 'abonos', 'credito'));
    }

    public function listDataToCajaForCierre($tipo = 'Entrada')
    {
        return  Caja::where([
            ['tipo', $tipo]
        ])
            ->whereDate('created_at', date('Y-m-d'))
            ->get();
    }

    public function getmovimientoToDate(Request $request)
    {
        $entradas =  Caja::where('tipo', 'Entrada')->whereBetween('created_at', [$request->inicio, $request->fin])->get();
        $salidas =  Caja::where('tipo', 'Salida')->whereBetween('created_at', [$request->inicio, $request->fin])->get();
        $recesos = CuadreReceso::whereBetween('created_at', [$request->inicio, $request->fin])->get();
        $cierres = Cierre::whereBetween('created_at', [$request->inicio, $request->fin])->get();
        $ventas = Venta::whereBetween('created_at', [$request->inicio, $request->fin])->get();
        $abonos = AbonoEstuiante::whereBetween('created_at', [$request->inicio, $request->fin])->get();
        $credito = CreditoEstuiante::whereBetween('created_at', [$request->inicio, $request->fin])->get();

        return view('admin.repote.fecha', compact(
            'entradas',
            'salidas',
            'recesos',
            'cierres',
            'ventas',
            'abonos',
            'credito'

        ));
    }

    public function getMenuToFecha(Request $request)
    {
        $lunes = Menu::where('dia', 'LUNES')->where('f_inicio', '>=', $request->inicio)->where('f_fin', '<', $request->fin)->get();
        $martes = Menu::where('dia', 'MARTES')->where('f_inicio', '>=', $request->inicio)->where('f_fin', '<', $request->fin)->get();
        $miercoles = Menu::where('dia', 'MIERCOLES')->where('f_inicio', '>=', $request->inicio)->where('f_fin', '<', $request->fin)->get();
        $jueves = Menu::where('dia', 'JUEVES')->where('f_inicio', '>=', $request->inicio)->where('f_fin', '<', $request->fin)->get();
        $viernes = Menu::where('dia', 'VIERNES')->where('f_inicio', '>=', $request->inicio)->where('f_fin', '<', $request->fin)->get();



        return view('admin.repote.menu', compact(

            'lunes',
            'martes',
            'miercoles',
            'jueves',
            'viernes',

        ));
    }
}
